# auto_adpq

[![codecov](https://codecov.io/github/Tfloow/auto_adpq/branch/main/graph/badge.svg)](https://codecov.io/github/Tfloow/auto_adpq)


---

This repo aims at replicating [AdpQ: A Zero-shot Calibration Free Adaptive Post Training Quantization Method for LLMs](https://arxiv.org/abs/2405.13358) since no public repo seems to propose it

```
# Install the package

pip install -e .

# Install the build tools

pip install -e .[dev]
```